@@ -32,6 +32,9 @@ class Aurora():
         # Import the config module
         self.config = importlib.import_module("config")
 
+        # Developement mode
+        self.development = getattr(self.config, "DEVELOPMENT")
+
         # Debug mode
         self.debug = getattr(self.config, "DEBUG")
 
@@ -338,15 +341,17 @@ class Aurora():
     # 
     # @return object: NoneType -- The root app
     ##
-    def run(self, host:str=None, port:str=None, debug:bool=None):  
+    def run(self, *class_args, **class_kwargs):    
         # Fetch the required attributes
-        host = getattr(self.config, "HOST") if host == None else host
-        port = getattr(self.config, "PORT") if port == None else port
-        debug = self.debug if debug == None else debug
+        host = getattr(self.config, "HOST")
+        port = getattr(self.config, "PORT")
 
         # Try to run the app
         try:
-            return self.app.run(host=host, port=port, debug=debug)
+            if self.development:
+                return self.app.run(host=host, port=port, debug=self.debug)
+            else:
+                return self.app.run(*class_args, **class_kwargs)
 
         except NameError as e:
             # Developer mode
